==> c2cgeoportal-2.0.0.dev11-py2.py3-none-any.whl: c2cgeoportal/scripts/print_tpl.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2011-2016, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import os
from mako.template import Template
from mako.lookup import TemplateLookup


def main():
    """ This function build the print configuration file config.yaml using
    mako.
    The file is created in the folder print/.
    If the file print/templates/print.mako doesnt exists, the build is not
    executed
    """

    base_template = 'print/templates/print.mako'
    if os.path.exists(base_template):
        print "building print template"

        # DONT! add a trailing / to the lookup path, mako cant find templates otherwise
        mylookup = TemplateLookup(directories=['print/templates'])
        mytemplate = Template(filename=base_template, lookup=mylookup)

        print_template = open('print/config.yaml', 'w+')
        print_template.write(mytemplate.render().encode('UTF-8'))
        print_template.close()

        print "finished building print template"
    else:
        print "no print template found, ignoring"

==> c2cgeoportal-2.2.0rc3-py2.py3-none-any.whl: c2cgeoportal/scripts/print_tpl.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2011-2017, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import os
from mako.template import Template
from mako.lookup import TemplateLookup


def main():
    """ This function build the print configuration file config.yaml using
    mako.
    The file is created in the folder print/.
    If the file print/templates/print.mako doesn't exists, the build is not
    executed
    """

    base_template = 'print/templates/print.mako'
    if os.path.exists(base_template):
        print("building print template")

        # DON'T! add a trailing / to the lookup path, mako can't find templates otherwise
        mylookup = TemplateLookup(directories=['print/templates'])
        mytemplate = Template(filename=base_template, lookup=mylookup)

        print_template = open('print/config.yaml', 'w+')
        print_template.write(mytemplate.render().encode('UTF-8'))
        print_template.close()

        print("finished building print template")
    else:
        print("no print template found, ignoring")
